@@ -530,6 +530,7 @@ class Tio2Jira:
             observed_since (int):
                 Unix Timestamp detailing the threshold for vuln age.
         '''
+        observed_since = int(observed_since)
         tags = list()
         for tag in self.config['tenable'].get('tio_tags', list()):
             tags.append((tag['key'], tag['value']))
@@ -589,8 +590,8 @@ class Tio2Jira:
                 for tag in asset['tags']:
                     # Generate the tag name to use.
                     tag_name = '{key}:{value}'.format(
-                        key=tag['key'],
-                        value=tag['value']
+                        key=tag['key'].replace(' ', '_'),
+                        value=tag['value'].replace(' ', '_')
                     )
 
                     # If the tag name isn't in the cached list, then add it.
